selectortools
=============

.. automodule:: abjad.tools.selectortools

.. only:: html

   Abstract classes
   ----------------

   .. autosummary::

      ~abjad.tools.selectortools.Inequality.Inequality

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.selectortools.ContiguitySelectorCallback.ContiguitySelectorCallback
      ~abjad.tools.selectortools.CountsSelectorCallback.CountsSelectorCallback
      ~abjad.tools.selectortools.DurationInequality.DurationInequality
      ~abjad.tools.selectortools.DurationSelectorCallback.DurationSelectorCallback
      ~abjad.tools.selectortools.ExtraLeafSelectorCallback.ExtraLeafSelectorCallback
      ~abjad.tools.selectortools.FlattenSelectorCallback.FlattenSelectorCallback
      ~abjad.tools.selectortools.ItemSelectorCallback.ItemSelectorCallback
      ~abjad.tools.selectortools.LengthInequality.LengthInequality
      ~abjad.tools.selectortools.LengthSelectorCallback.LengthSelectorCallback
      ~abjad.tools.selectortools.LogicalMeasureSelectorCallback.LogicalMeasureSelectorCallback
      ~abjad.tools.selectortools.LogicalTieSelectorCallback.LogicalTieSelectorCallback
      ~abjad.tools.selectortools.PatternedSelectorCallback.PatternedSelectorCallback
      ~abjad.tools.selectortools.PitchSelectorCallback.PitchSelectorCallback
      ~abjad.tools.selectortools.PrototypeSelectorCallback.PrototypeSelectorCallback
      ~abjad.tools.selectortools.RunSelectorCallback.RunSelectorCallback
      ~abjad.tools.selectortools.Selector.Selector
      ~abjad.tools.selectortools.SliceSelectorCallback.SliceSelectorCallback

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.selectortools.select_all_but_first_logical_tie_in_pitched_runs.select_all_but_first_logical_tie_in_pitched_runs
      ~abjad.tools.selectortools.select_all_but_last_logical_tie_in_pitched_runs.select_all_but_last_logical_tie_in_pitched_runs
      ~abjad.tools.selectortools.select_first_logical_tie_in_pitched_runs.select_first_logical_tie_in_pitched_runs
      ~abjad.tools.selectortools.select_last_logical_tie_in_pitched_runs.select_last_logical_tie_in_pitched_runs
      ~abjad.tools.selectortools.select_pitched_runs.select_pitched_runs
